==> haskell-abstract-deque-0.3-248-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 abstract-deque
version:              0.3
visibility:           public
id:                   abstract-deque-0.3-Hc5kS3WM0P2AT6Ou9IBSU2
key:                  abstract-deque-0.3-Hc5kS3WM0P2AT6Ou9IBSU2
license:              BSD-3-Clause
maintainer:           rrnewton@gmail.com
author:               Ryan R. Newton
homepage:             https://github.com/rrnewton/haskell-lockfree/wiki
synopsis:             Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.

    Background: There exists a feature space for queues that extends between:

    * simple, single-ended, non-concurrent, bounded queues

    * double-ended, threadsafe, growable queues

    ... with important points inbetween (such as
    the queues used for work-stealing).

    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).

    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".

category:             Data 
abi:                  71258a38e87e68b009fdb0425cde9221
exposed:              True
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Debugger
    Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance

import-dirs:          /usr/lib/ghc-9.4.8/site-local/abstract-deque-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/abstract-deque-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/abstract-deque-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-abstract-deque
hs-libraries:         HSabstract-deque-0.3-Hc5kS3WM0P2AT6Ou9IBSU2
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    random-1.2.1.3-2HbxmMbiRhQI1KxtG7s1TV time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock

haddock-html:         /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-abstract-deque-0.3-249-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 abstract-deque
version:              0.3
visibility:           public
id:                   abstract-deque-0.3-LMYuEkIj3P9GruMlNmPMkg
key:                  abstract-deque-0.3-LMYuEkIj3P9GruMlNmPMkg
license:              BSD-3-Clause
maintainer:           rrnewton@gmail.com
author:               Ryan R. Newton
homepage:             https://github.com/rrnewton/haskell-lockfree/wiki
synopsis:             Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.

    Background: There exists a feature space for queues that extends between:

    * simple, single-ended, non-concurrent, bounded queues

    * double-ended, threadsafe, growable queues

    ... with important points inbetween (such as
    the queues used for work-stealing).

    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).

    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".

category:             Data 
abi:                  8d19fab35ed678810320e4db59b95d69
exposed:              True
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Debugger
    Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance

import-dirs:          /usr/lib/ghc-9.4.8/site-local/abstract-deque-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/abstract-deque-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/abstract-deque-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-abstract-deque
hs-libraries:         HSabstract-deque-0.3-LMYuEkIj3P9GruMlNmPMkg
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    random-1.2.1.3-6Q31h3pRIgvDA2QDH6tJjk time-1.12.2

haddock-interfaces:
    /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock

haddock-html:         /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
